using C1.Win.Chart;
using System.ComponentModel;
using System.Data;
using System.Data.OleDb;

namespace FlexChart_PointNotes
{
    public partial class Form1 : Form
    {
        FlexChart _chart;
        DataSet _data;
        OleDbDataAdapter _adapter;
        public Form1()
        {
            InitializeComponent();

            _adapter = new("select * from TestData", GetConnectionString());
            var cb = new OleDbCommandBuilder(_adapter);
            cb.QuotePrefix = "[";
            cb.QuoteSuffix = "]";
            _adapter.UpdateCommand = cb.GetUpdateCommand();
            _data = new();
            _adapter.Fill(_data);
            _data.Tables[0].PrimaryKey =
            [
                _data.Tables[0].Columns["X"]!
            ];

            var rnd = new Random();
            this.Controls.Add(_chart = new()
            {
                Dock = DockStyle.Fill,
                DataSource = _data.Tables[0],
                BindingX = "X",
                Binding = "Y",
                ChartType = C1.Chart.ChartType.LineSymbols,
                AxisY =
                {
                    Min = 0,
                    Max = 12
                },
                Series =
                {
                    new Series()
                },
                ToolTip =
                {
                    Content = "(X: {X}, Y: {Y})\n\nNote: {Note}"
                },
                ContextMenuStrip = contextMenuStrip1
            });
            contextMenuStrip1.Opening += ContextMenuStrip1_Opening;
        }

        int _currPoint;

        private void ContextMenuStrip1_Opening(object? sender, CancelEventArgs e)
        {
            var info = _chart.HitTest(_chart.PointToClient(MousePosition));

            e.Cancel = !(info != null && info.Distance == 0);

            if (!e.Cancel)
                _currPoint = int.Parse((info!.Item as DataRowView)!["X"].ToString()!);
        }

        private void editNoteToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var row = _data.Tables[0].Rows.Find(_currPoint)!;
            var noteForm = new NoteForm(row["Note"].ToString()!);
            if(noteForm.ShowDialog()== DialogResult.OK)
            {
                row["Note"] = noteForm.Note;
            }
        }

        static string GetConnectionString()
        {
            //if process is 32bit use JET.OLEDB otherwise use ACE.OLEDB
            return $"Provider={(Environment.Is64BitProcess ? "Microsoft.Ace.OLEDB.12.0" : "Microsoft.Jet.OLEDB.4.0")};Data Source=./../../../TestDB.mdb;";
        }

        protected override void OnFormClosing(FormClosingEventArgs e)
        {
            _adapter.Update(_data);
            base.OnFormClosing(e);
        }
    }
}
